@@ -908,8 +908,8 @@ eog_image_new_pixbuf_loader (EogImage 	*img,
 		priv->svg = NULL;
 	}
 
-	if (!strcmp (mime_type, "image/svg+xml")
-		    || !strcmp (mime_type, "image/svg+xml-compressed")
+	if (!g_strcmp0 (mime_type, "image/svg+xml")
+		    || !g_strcmp0 (mime_type, "image/svg+xml-compressed")
 	    ) {
 		/* Keep the object for rendering */
 		priv->svg = rsvg_handle_new ();
@@ -924,11 +924,12 @@ eog_image_new_pixbuf_loader (EogImage 	*img,
 #endif
 
 	if (!(*is_svg)) {
-		loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, error);
+		if (G_LIKELY (mime_type))
+			loader = gdk_pixbuf_loader_new_with_mime_type (mime_type,
+								       error);
 
-		if (error && *error) {
-			g_error_free (*error);
-			*error = NULL;
+		if (loader == NULL) {
+			g_clear_error (error);
 
 			loader = gdk_pixbuf_loader_new ();
 		}
@@ -1123,7 +1124,7 @@ eog_image_real_load (EogImage     *img,
 			if (eog_job_is_cancelled (job)) {
 				eog_image_cancel_load (img);
 				continue;
-			} else {
+			} else if (priv->bytes > 0.0) {
 				float progress = (float) bytes_read_total / (float) priv->bytes;
 				eog_job_set_progress (job, progress);
 			}
@@ -1788,7 +1789,7 @@ check_if_file_is_writable (GFile *file)
 	GFile           *file_to_check;
 	GFileInfo	*file_info;
 	GError		*error = NULL;
-	gboolean	 is_writable;
+	gboolean	 is_writable, has_writable;
 
 	g_return_val_if_fail (G_IS_FILE (file), FALSE);
 
@@ -1822,9 +1823,16 @@ check_if_file_is_writable (GFile *file)
 		return FALSE;
 	}
 
-	/* check if file can be writed */
-	is_writable = g_file_info_get_attribute_boolean (file_info,
-							 G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+	/* check if file can be written */
+	has_writable = g_file_info_has_attribute (file_info,
+					          G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+	if (has_writable) {
+		is_writable = g_file_info_get_attribute_boolean (file_info,
+								 G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+	} else {
+		/* try writing the file when the writable attribute is absent */
+		is_writable = TRUE;
+	}
 
 	/* free objects */
 	g_object_unref (file_info);
